<?php

namespace Bixo\Car\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Car\Actions\CarAction;
use Bixo\Car\Http\Requests\CarActionRequest;
use Bixo\Car\Http\Resources\CarResource;
use Bixo\Car\Models\Car;

/**
 * Admin web controller class.
 */
class CarActionController extends BaseController
{

    /**
     * Action controller function for car.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CarActionRequest $request, Car $car, $action)
    {
        try {
            $request = $request->all();
            $car = CarAction::run($action, $car, $request);

            $data = new CarResource($car);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('car::car.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('car/car/' . $car->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('car/car/' . $car->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
