<?php

namespace Bixo\Car\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Bixo\Car\Actions\CarExim;
use Bixo\Car\Http\Requests\CarEximRequest;

/**
 * Admin web controller class.
 */
class CarEximController extends BaseController
{
    /**
     * Action controller function for car.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CarEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = CarExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('car:car.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('car/car/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('car/car/' . $exim))
                ->redirect();
        }
    }
}
