<?php

namespace Bixo\Car\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Car\Events\CarAction as CarActionEvent;
use Bixo\Car\Notifications\CarAction as CarActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CarAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CarActionEvent.
     *
     * @param   CarActionEvent  $event
     * @return mixed
     */
    public function handle(CarActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $car.
     *
     * @param   CarActionEvent  $event
     * @return void
     */
    public function create(CarActionEvent $event)
    {
        $client = $event->car->client;
        Notification::send($client, new CarActionNotification($event));
    }

    /**
     * Handle the CarActionEvent as a listener.
     *
     * @param   CarActionEvent  $event
     * @return mixed
     */
    public function asListener(CarActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CarActionEvent  $event
     * @return bool
     */
    private function isAllowed(CarActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
