<?php

namespace Bixo\Car\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Car\Models\Car;

class CarPolicy
{

    use CarAction;
    use CarExim;
    use CarReport;
    use CarWorkflow;

    /**
     * Determine if the given user can view the car.
     *
     * @param Authenticatable $user
     * @param Car $car
     *
     * @return bool
     */
    public function view(Authenticatable $user, Car $car)
    {
        if ($authUser->canDo('car.car.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $car->is_owner;
    }

    /**
     * Determine if the given user can create a car.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('car.car.create');
    }

    /**
     * Determine if the given user can update the given car.
     *
     * @param Authenticatable $user
     * @param Car $car
     *
     * @return bool
     */
    public function update(Authenticatable $user, Car $car)
    {
        if ($user->canDo('car.car.edit') && $user->isAdmin()) {
            return true;
        }

        return $car->is_owner;
    }

    /**
     * Determine if the given user can delete the given car.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Car $car)
    {
        return $car->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
